@@ -22,14 +22,10 @@
 
 require_once ('../include/init.php');
 require_once ('../include/database.php');
-require_once ('../include/dnsbl.php');
 require_once ('../include/spam.php');
 require_once ('../include/sane.php');
 require_once ('../include/sendmail.php');
 
-# Block here potential robots.
-dnsbl_check ();
-
 extract (sane_import ('get', ['name' => 'form_user']));
 $res_user = db_execute ("SELECT * FROM user WHERE user_name = ?", [$form_user]);
 $row_user = NULL;
@@ -41,22 +37,17 @@ if (empty ($row_user) || $row_user['status'] != 'P')
   exit_error (_("Error"), _("This account is not pending verification."));
 
 $message =
-  sprintf (
-    _("Thank you for registering on the %s web site."),
-    $GLOBALS['sys_name']
-  )
+  sprintf (_("Thank you for registering on the %s web site."), $sys_name)
   . "\n"
   . _("In order to complete your registration, visit the following URL:")
-  . "\n\n" . $GLOBALS['sys_https_url'] . $GLOBALS['sys_home']
+  . "\n\n$sys_https_url$sys_home"
   . "account/verify.php?confirm_hash=$row_user[confirm_hash]\n\n"
   . _("Enjoy the site.") . "\n\n";
 # TRANSLATORS: the argument is the name of the system (like "Savannah").
-$message .= sprintf(_("-- the %s team."), $GLOBALS['sys_name']) . "\n";
+$message .= sprintf (_("-- the %s team."), $sys_name) . "\n";
 sendmail_mail (
-  $GLOBALS['sys_mail_replyto'] . "@" . $GLOBALS['sys_mail_domain'],
-  $row_user['email'],
-  $GLOBALS['sys_name'] . " " . _("Account Registration"),
-  $message
+  ['from' => "$sys_mail_replyto@$sys_mail_domain", 'to' => $row_user['email']],
+  ['subject' => "$sys_name " . _("Account Registration"), 'body' => $message]
 );
 
 $HTML->header (['title' => _("Account Pending Verification")]);
