@@ -44,6 +44,9 @@ if (db_numrows ($res_grp) < 1)
 
 session_require (['group' => $group_id, 'admin_flags' => 'A']);
 $key_func = ['preg', '/^(([\d]+)|(new))$/'];
+$email_regex =
+   '([a-zA-Z0-9_.+-]+@(([a-zA-Z0-9-])+\.)+[a-zA-Z0-9]+,)*'
+   . '([a-zA-Z0-9_.+-]+@(([a-zA-Z0-9-])+\.)+[a-zA-Z0-9]+)';
 extract (sane_import ('post',
   [
     'true' => 'log_accum',
@@ -66,16 +69,8 @@ extract (sane_import ('post',
           ['preg', '/^(([a-zA-Z0-9_.+\/-]+,)*([a-zA-Z0-9_.+\/-]+))$/']
         ]
       ],
-      ['arr_emails_notif', 'arr_emails_diff',
-        [
-          $key_func,
-          [
-            'preg',
-            '/^([a-zA-Z0-9_.+-]+@(([a-zA-Z0-9-])+\.)+[a-zA-Z0-9]+,)*'
-            . '([a-zA-Z0-9_.+-]+@(([a-zA-Z0-9-])+\.)+[a-zA-Z0-9]+)$/'
-          ]
-        ]
-      ],
+      ['arr_emails_notif', [$key_func, ['preg', "/^$email_regex" . '$/']]],
+      ['arr_emails_diff', [$key_func, ['preg', "/^($email_regex)|$/"]]],
       ['arr_enable_diff', [$key_func, ['digits', [1, 1]]]]
     ]
   ]));
@@ -103,29 +98,25 @@ if (isset ($log_accum))
             continue;
           if (!isset ($arr_match_type[$hook_id]))
             continue;
+          if (empty ($arr_emails_notif[$hook_id]))
+            continue;
           $repo_name = $arr_repo_name[$hook_id];
           $match_type = $arr_match_type[$hook_id];
           $dir_list = null;
-          if (isset ($arr_dir_list[$hook_id]) && $match_type == 'dir_list')
+          if (isset ($arr_dir_list[$hook_id]))
             $dir_list = $arr_dir_list[$hook_id];
           $branches = null;
           if (isset ($arr_branches[$hook_id])
-              && $arr_branches[$hook_id] != '')
+              && $arr_branches[$hook_id] !== '')
             $branches = $arr_branches[$hook_id];
           $enable_diff = '0';
-          if (isset($arr_enable_diff[$hook_id]))
+          if (!empty ($arr_enable_diff[$hook_id]))
             $enable_diff = $arr_enable_diff[$hook_id];
-          $emails_notif = null;
-          if (isset ($arr_emails_notif[$hook_id]))
-            $emails_notif = $arr_emails_notif[$hook_id];
-          if ($emails_notif === null)
-            continue;
+          $emails_notif = $arr_emails_notif[$hook_id];
           $emails_diff = null;
           if (isset ($arr_emails_diff[$hook_id])
-              && $arr_emails_diff[$hook_id])
+              && $arr_emails_diff[$hook_id] !== '')
             $emails_diff = $arr_emails_diff[$hook_id];
-          if ($enable_diff && $emails_diff === null)
-            continue;
 
           if ($hook_id == 'new')
             {
@@ -181,11 +172,15 @@ print "<table>\n";
 print html_build_list_table_top (
   [
     html_image_trash (['alt' => _("Delete")]),
-    _('Repository'), _('Match type'), _('Module list'), _('Branch filter'),
-    _('Notification to'), _('Diff?'), _('Separate diffs to')
+    _('Repo'), _('Match'), _('Modules'), _('Branches'),
+    _('Send to'), _('Diff?'), _('Diffs to')
   ]
 );
 
+$repo_keys =  ['sources', 'web'];
+# TRANSLATORS: this is the type of repository (sources  or web).
+$repo_vals = [_('sources'), _('web')];
+
 while ($row = db_fetch_array ($result))
   {
     $cur= $row['hook_id'];
@@ -193,23 +188,23 @@ while ($row = db_fetch_array ($result))
     print form_hidden (["arr_id[$cur]" => "$cur"]);
     print form_checkbox ("arr_remove[$cur]", 0);
     print "</td>\n<td>";
-    print html_build_select_box_from_array (
-      ['sources', 'web'], "arr_repo_name[$cur]", $row['repo_name'], 1
+    print html_build_select_box_from_arrays (
+      $repo_keys, $repo_vals, "arr_repo_name[$cur]", $row['repo_name'], false
     );
     print "</td>\n<td>";
     print match_type_box ("arr_match_type[$cur]", $row['match_type']);
     print "</td>\n";
     print "<td><input type='text' name='arr_dir_list[$cur]' "
-      . "value='{$row['dir_list']}' /></td>\n";
+      . "value='{$row['dir_list']}' size='10' /></td>\n";
     print "<td><input type='text' name='arr_branches[$cur]' "
-      . "value='{$row['branches']}' /></td>\n";
+      . "value='{$row['branches']}' size='10' /></td>\n";
     print "<td><input type='text' name='arr_emails_notif[$cur]' "
-      . "value='{$row['emails_notif']}' /></td>\n";
+      . "value='{$row['emails_notif']}' size='13' /></td>\n";
     print "<td>";
     print form_checkbox ("arr_enable_diff[$cur]", $row['enable_diff']);
     print "</td>\n";
     print "<td><input type='text' name='arr_emails_diff[$cur]' "
-      . "value='{$row['emails_diff']}' /></td>\n";
+      . "value='{$row['emails_diff']}' size='13' /></td>\n";
     print "</tr>\n";
   }
 
@@ -222,18 +217,12 @@ print "<h2>" . _("New notification") . "</h2>\n";
 print form_tag ([], "?group=$group");
 print "<ol>\n";
 print "<li>" . _("Repository:") . " ";
-print html_build_select_box_from_array (
-  [
-    # TRANSLATORS: this is the type of repository (sources  or web).
-    _('sources'),
-    # TRANSLATORS: this is the type of repository (sources  or web).
-    _('web')
-  ],
-  "arr_repo_name[new]", $row['repo_name'], 1
+print html_build_select_box_from_arrays (
+  $repo_keys, $repo_vals, "arr_repo_name[new]", 'xzxz', false
 );
 print "</li>\n<li>";
 print _("Matching type:") . " ";
-print match_type_box ("arr_match_type[new]", $row['match_type']);
+print match_type_box ("arr_match_type[new]", 'xzxz');
 print "<ul>
   <li>" . _("<i>Always</i> is always performed (even in addition to Fallback)")
   . "</li>
@@ -250,29 +239,29 @@ print _("Filter by directory: if match is <i>Module list</i>, enter a list of
   directories.<br />
   Leave blank if you want to get notifications for all the repository:")
   . "<br />";
-print "<input type='text' name='arr_dir_list[new]' value='{$row['dir_list']}' />";
+print "<input type='text' name='arr_dir_list[new]' value='' />";
 print "</li>\n<li>";
 print _("List of comma-separated emails to send notifications to, e.g.
   winnie@the-pooh.mil, yu@guan.edu):") . "<br />";
 print "<input type='text' name='arr_emails_notif[new]' "
-  . "value='{$row['emails_notif']}' />";
+  . "value='' />";
 print "</li>\n<li>";
 print _("Send diffs?") . " ";
-print form_checkbox ("arr_enable_diff[new]", $row['enable_diff']);
+print form_checkbox ("arr_enable_diff[new]", 0);
 print "</li>\n<li>";
 print _("Optional alternate list of emails to send diffs separately to, e.g.
   winnie@the-pooh.mil, yu@guan.edu.<br />
   If empty, the diffs will be included in commit notifications:")
   . "<br />";
 print "<input type='text' name='arr_emails_diff[new]' "
-  . "value='{$row['emails_diff']}' />\n";
+  . "value='' />\n";
 print "</li>\n<li>";
 print _("Filter by branch: you will be notified only commits in these branches,
   separated by commas.<br />
   Enter <i>HEAD</i> if you only want trunk commits.<br />
   Leave blank to get notifications for all commits:")
   . "<br />";
-print "<input type='text' name='arr_branches[new]' value='{$row['branches']}' />";
+print "<input type='text' name='arr_branches[new]' value='' />";
 print "</li>\n</ol>\n";
 print "<input type='hidden' name='arr_id[new]' value='new' />\n";
 $caption = _('Add');
