@@ -5,7 +5,7 @@
 # Copyright (C) 2003-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2007, 2008  Sylvain Beucler
 # Copyright (C) 2008  Nicodemo Alvaro
-# Copyright (C) 2017, 2018, 2021, 2022 Ineiev
+# Copyright (C) 2017, 2018, 2021, 2022, 2023 Ineiev
 #
 # This file is part of Savane.
 #
@@ -115,6 +115,9 @@ function search_box ($searched_words = '', $scope = null, $size = 15)
   global $words, $group_id, $exact, $type_of_search, $type, $max_rows;
   global $only_group_id;
 
+  if (!is_scalar ($searched_words))
+    $searched_words = '';
+
   $gid = null;
   if (!empty ($group_id))
     $gid = $group_id;
@@ -135,8 +138,6 @@ function search_box ($searched_words = '', $scope = null, $size = 15)
   # If there is no search currently, set the default.
   if (!isset ($type_of_search))
     $exact = 1;
-  if (!isset ($max_rows))
-    $max_rows = "25";
 
   # If the wildcard '%%%' is searched, replace it with the more usual '*'.
   if ($words == "%%%")
@@ -174,8 +175,8 @@ function search_box ($searched_words = '', $scope = null, $size = 15)
                ' selected="selected"' : "")
             . '>'
             # TRANSLATORS: this string is used in the context
-            # of "Search [...] in Projects"
-            . _("Projects") . "</option>\n";
+            # of "Search [...] in Groups"
+            . _("Groups") . "</option>\n";
 
           $sel .= '<option value="people"'
             . (($type_of_search == "people") ? ' selected="selected"' : "")
@@ -189,7 +190,7 @@ function search_box ($searched_words = '', $scope = null, $size = 15)
         . "</select>\n";
 
       # TRANSLATORS: this word is used in the phrase "Search [...] in
-      # [Projects|People|Support|Bugs|Tasks|Patches]"
+      # [Groups|People|Support|Bugs|Tasks|Patches]"
       # in the main menu on the left side.
       # Make sure to put this piece in agreement with the following strings.
       $ret .= sprintf (' ' . _("in %s"), $sel);
@@ -243,15 +244,15 @@ function search_box ($searched_words = '', $scope = null, $size = 15)
             # of "Search [...] in any group type"
             . _("any") . "</option>\n";
           $result =
-            db_query("SELECT type_id,name FROM group_type ORDER BY type_id");
-          while ($eachtype = db_fetch_array($result))
+            db_query ("SELECT type_id, name FROM group_type ORDER BY type_id");
+          while ($eachtype = db_fetch_array ($result))
             {
               $sel_attr = '';
               if ($type == $eachtype['type_id'])
                  $sel_attr = ' selected="selected"';
-              $select .=
-                "<option value=\"{$eachtype['type_id']}\"$sel_attr>"
-                . "{$eachtype['name']}</option>\n";
+              $val = $eachtype['type_id'];
+              $name = gettext ($eachtype['name']);
+              $select .= "<option value=\"$val\"$sel_attr>$name</option>\n";
             }
           $select .= "</select>\n";
 
@@ -259,7 +260,7 @@ function search_box ($searched_words = '', $scope = null, $size = 15)
           # (like Official GNU software).
           $ret .=
              sprintf (
-               _("Search in %s group type, when searching for a Project."),
+               _("Search in %s group type, when searching for a group."),
                $select
              );
         } # !isset ($gid)
@@ -294,78 +295,61 @@ function search_send_header ()
 }
 
 # Search results for XXX (in YYY):
-# e.g.: Search results for emacs (in Projects):
-function print_search_heading()
+# e.g.: Search results for emacs (in groups):
+function print_search_heading ()
 {
-  global $words,$type_of_search,$only_group_id;
-  # Print the result
-  print '<h2 id="results">'._('Search results')."</h2>\n";
+  global $words, $type_of_search, $only_group_id;
+  print '<h2 id="results">' . _('Search results') . "</h2>\n";
   if (!($words && $type_of_search))
     return;
   print "<p>";
   # Print real words describing the type of search.
   if ($type_of_search == "soft")
-# TRANSLATORS: this string is the section to look in; it is used as the second
-# argument in 'Search results for %1$s (in %2$s)'.
-    $type_of_search_real = _("Projects");
+    # TRANSLATORS: this string is the section to look in; it is used as
+    # the second argument in 'Search results for %1$s (in %2$s)'.
+    $type_of_search_real = _("Groups");
   elseif ($type_of_search == "support")
-# TRANSLATORS: this string is the section to look in; it is used as the second
-# argument in 'Search results for %1$s (in %2$s)'.
-# The HTML comment is used to differentiate the usages of the same English string.
+    # TRANSLATORS: this string is the section to look in; it is used as
+    # the second argument in 'Search results for %1$s (in %2$s)'. The HTML
+    # comment is used to differentiate the usages of the same English string.
     $type_of_search_real = _("<!-- Search... in -->Support");
   elseif ($type_of_search == "bugs")
-# TRANSLATORS: this string is the section to look in; it is used as the second
-# argument in 'Search results for %1$s (in %2$s)'.
-# The HTML comment is used to differentiate the usages of the same English string.
     $type_of_search_real = _("<!-- Search... in -->Bugs");
   elseif ($type_of_search == "task")
-# TRANSLATORS: this string is the section to look in; it is used as the second
-# argument in 'Search results for %1$s (in %2$s)'.
-# The HTML comment is used to differentiate the usages of the same English string.
     $type_of_search_real = _("<!-- Search... in -->Tasks");
   elseif ($type_of_search == "patch")
-# TRANSLATORS: this string is the section to look in; it is used as the second
-# argument in 'Search results for %1$s (in %2$s)'.
-# The HTML comment is used to differentiate the usages of the same English string.
     $type_of_search_real = _("<!-- Search... in -->Patches");
   elseif ($type_of_search == "people")
-# TRANSLATORS: this string is the section to look in; it is used as the second
-# argument in 'Search results for %1$s (in %2$s)'.
-# The HTML comment is used to differentiate the usages of the same English string.
     $type_of_search_real = _("<!-- Search... in -->People");
 
   if (!$only_group_id)
-    {
-# TRANSLATORS: the first argument is string to look for,
-# the second argument is section (Project/Group|Support|Bugs|Task
-#   |Patch|People).
-      printf(_('Search results for %1$s in %2$s:'),
-             '<strong>'.htmlspecialchars($words).'</strong>',
-             $type_of_search_real);
-    }
+    # TRANSLATORS: the first argument is string to look for,
+    # the second argument is section (Group|Support|Bugs|Task|Patch|People).
+    printf (_('Search results for %1$s in %2$s:'),
+      '<strong>' . htmlspecialchars ($words) . '</strong>',
+      $type_of_search_real
+    );
   else
-    {
-# TRANSLATORS: the first argument is string to look for,
-# the second argument is section (Support|Bugs|Task
-#   |Patch|People), the third argument is
-# group name (like GNU Coreutils).
-      printf(_('Search results for %1$s in %2$s, for the Group %3$s:'),
-             '<strong>'.htmlspecialchars($words).'</strong>',
-             $type_of_search_real, group_getname($only_group_id));
-    }
+    # TRANSLATORS: the first argument is string to look for, the second
+    # argument is section (Support|Bugs|Task|Patch|People), the third argument
+    # is group name (like GNU Coreutils).
+    printf (_('Search results for %1$s in %2$s, for the Group %3$s:'),
+      '<strong>' . htmlspecialchars ($words) . '</strong>',
+      $type_of_search_real, group_getname ($only_group_id)
+    );
   print "</p>\n";
 }
 
 function result_no_match ()
 {
-  return search_failed();
+  return search_failed ();
 }
 
 function search_failed ()
 {
-  global $no_rows,$words;
+  global $no_rows, $words;
   $no_rows = 1 ;
-  search_send_header();
+  search_send_header ();
   print '<span class="warn">';
   print _("None found. Please note that only search words of more than two
 characters are valid.");
@@ -373,50 +357,54 @@ characters are valid.");
   print db_error();
 }
 
-// Build
-// "((field1 LIKE '%kw1%' and/or field1 LIKE '%kw2%' ...)
-//   or (field2 LIKE '%kw1%' and/or field2 LIKE '%kw2%' ...)
-//   ...)"
-// + matching parameters array, suitable for db_execute()
-// $and_or <=> 'AND'/'OR' <=> all/any word
-function search_keywords_in_fields($keywords, $fields, $and_or='OR')
+# Build
+# "((field1 LIKE '%kw1%' and/or field1 LIKE '%kw2%' ...)
+#   or (field2 LIKE '%kw1%' and/or field2 LIKE '%kw2%' ...)
+#   ...)"
+# + matching parameters array, suitable for db_execute()
+# $and_or <=> 'AND'/'OR' <=> all/any word
+function search_keywords_in_fields ($keywords, $fields, $and_or = 'OR')
 {
-  $allfields_sql_bits = array();
-  $allfields_sql_params = array();
+  $allfields_sql_bits = $allfields_sql_params = [];
   foreach ($fields as $field)
     {
-      $thisfield_sql_bits = array();
-      $thisfield_sql_params = array();
+      $thisfield_sql_bits = $thisfield_sql_params = [];
       foreach($keywords as $keyword)
         {
           $thisfield_sql_bits[] = "$field LIKE ?";
           if (preg_match('/_id$/', $field))
-            {
-              # Strip "#" from, eg, "#153".
-              $thisfield_sql_params[] = '%'
-                                        . str_replace ('#', '', $keyword)
-                                        . '%';
-            }
+            # Strip "#" from, eg, "#153".
+            $thisfield_sql_params[] = '%'
+              . str_replace ('#', '', $keyword) . '%';
           else
-            $thisfield_sql_params[] = '%'.$keyword.'%';
+            $thisfield_sql_params[] = "%$keyword%";
         }
-      $allfields_sql_bits[] = '(' . implode(" $and_or ", $thisfield_sql_bits)
-                              . ')';
-      $allfields_sql_params = array_merge($allfields_sql_params,
-                                          $thisfield_sql_params);
+      $allfields_sql_bits[] =
+        '(' . join (" $and_or ", $thisfield_sql_bits) . ')';
+      $allfields_sql_params = array_merge (
+        $allfields_sql_params, $thisfield_sql_params
+      );
     }
-  $allfields_sql = '(' . implode(' OR ', $allfields_sql_bits) . ')';
-  return array($allfields_sql, $allfields_sql_params);
+  $allfields_sql = '(' . join (' OR ', $allfields_sql_bits) . ')';
+  return [$allfields_sql, $allfields_sql_params];
 }
 
 # Run a search in the database, by default in programs.
-function search_run ($keywords, $type_of_search="soft", $return_error_messages=1)
+function search_run (
+  $keywords, $type_of_search = "soft", $return_error_messages = 1
+)
 {
   global $type, $exact, $crit, $offset, $only_group_id, $max_rows;
   $and_or = $crit;
 
+  if (!is_scalar ($keywords))
+    {
+      search_failed ();
+      exit;
+    }
+
   # Remove useless blank spaces, escape nasty characters.
-  $keywords = trim($keywords);
+  $keywords = trim ($keywords);
 
   # Convert the wildcard * to the similar SQL one, when it is alone.
   if ($keywords == "*")
@@ -424,156 +412,138 @@ function search_run ($keywords, $type_of_search="soft", $return_error_messages=1
 
   # Replace the wildcard * to the similar SQL one, when included in a
   # word.
-  $keywords = strtr($keywords, "*", "%");
+  $keywords = strtr ($keywords, "*", "%");
 
   # Convert the crit form value to the SQL equiv.
   if ($exact)
-    $and_or='AND';
+    $and_or = 'AND';
   else
-    $and_or='OR';
-
-  # No offset defined? Start the search in the DB at 0.
-  if (!$offset || $offset < 0)
-    $GLOBALS['offset'] = 0;
-
-  # Print 25 rows by default.
-  if (!$max_rows)
-    $GLOBALS['max_rows'] = 25;
+    $and_or = 'OR';
 
   # Accept only to do a search for more than 2 characters.
   # Exit only if we were not told to avoid returning error messages.
   # Note: we tell user we want more than 3 characters, to incitate to
   # do clever searchs. But it will be ok for only 2 characters (limit
   # that conveniently allow us to search by items numbers).
-  if ($keywords && (strlen($keywords) < 3) && $return_error_messages)
+  if ($keywords && (strlen ($keywords) < 3) && $return_error_messages)
     {
-      search_failed();
+      search_failed ();
       exit;
     }
 
-  $arr_keywords = explode(" ", $keywords);
+  $arr_keywords = explode (" ", $keywords);
   $sql = '';
-  $sql_params = array();
+  $sql_params = [];
 
-  if ($type_of_search == "soft")
+  $tos = $type_of_search;
+  if ($tos == "soft")
     {
-      $sql = "SELECT group_name,unix_group_name,type,group_id,short_description "
-             ."FROM groups WHERE status='A' AND is_public='1' ";
+      $sql = "
+        SELECT group_name, unix_group_name, type, group_id, short_description
+        FROM groups WHERE status = 'A' AND is_public = '1' ";
       if ($type)
         {
-          $sql .= "AND type=? ";
+          $sql .= "AND type = ? ";
           $sql_params[] = $type;
         }
 
-      list($kw_sql, $kw_sql_params) = search_keywords_in_fields(
+      list ($kw_sql, $kw_sql_params) = search_keywords_in_fields (
         $arr_keywords,
-        array('group_name', 'short_description', 'unix_group_name', 'group_id'),
-        $and_or);
-      $sql .= " AND $kw_sql ORDER BY group_name,unix_group_name ";
+        ['group_name', 'short_description', 'unix_group_name', 'group_id'],
+        $and_or
+      );
+      $sql .= " AND $kw_sql ORDER BY group_name, unix_group_name ";
       $sql_params = array_merge($sql_params, $kw_sql_params);
     }
-  elseif ($type_of_search == "people")
+  elseif ($tos == "people")
     {
-      $sql = "SELECT user_name,user_id,realname "
-        . "FROM user WHERE status='A' ";
-
-      list($kw_sql, $kw_sql_params) = search_keywords_in_fields(
-        $arr_keywords,
-        array('user_name', 'realname', 'user_id'),
-        $and_or);
+      $sql = "SELECT user_name, user_id, realname FROM user WHERE status = 'A'";
 
+      list ($kw_sql, $kw_sql_params) = search_keywords_in_fields (
+        $arr_keywords, ['user_name', 'realname', 'user_id'], $and_or
+      );
       $sql .= " AND $kw_sql ORDER BY user_name ";
       $sql_params = array_merge($sql_params, $kw_sql_params);
     }
-  elseif ($type_of_search == 'bugs'
-          || $type_of_search == 'support'
-          || $type_of_search == 'patch'
-          || $type_of_search == 'cookbook'
-          || $type_of_search == 'task')
+  elseif (
+    !in_array ($tos, ['bugs', 'support', 'patch', 'cookbook', 'task'])
+  )
+    exit_error (_("Invalid search."));
+  else
     {
-      $sql = "SELECT " . $type_of_search . ".bug_id,"
-        . $type_of_search . ".summary,"
-        . $type_of_search . ".date,"
-        . $type_of_search . ".privacy,"
-        . $type_of_search . ".submitted_by, user.user_name,"
-        . $type_of_search . ".group_id "
-        . "FROM " . $type_of_search . ",user,groups "
-        . "WHERE user.user_id=" . $type_of_search . ".submitted_by "
-        . "AND groups.group_id=" . $type_of_search . ".group_id ";
-     if ($type_of_search != 'cookbook')
-       # As of 2021, we have no use_cookbook in the groups table.
-       $sql .= "AND groups.use_" . $type_of_search . "=1";
+      $sql = "
+        SELECT
+          $tos.bug_id, $tos.summary, $tos.date, $tos.privacy,
+          $tos.submitted_by, user.user_name, $tos.group_id
+        FROM $tos, user, groups
+        WHERE
+          user.user_id = $tos.submitted_by
+          AND groups.group_id = $tos.group_id ";
+      if ($tos != 'cookbook')
+        # As of 2021, we have no use_cookbook in the groups table.
+        $sql .= "AND groups.use_$tos = 1";
 
-      list($kw_sql, $kw_sql_params) = search_keywords_in_fields(
-        $arr_keywords,
-        array("{$type_of_search}.details", "{$type_of_search}.summary",
-              "{$type_of_search}.bug_id"),
-        $and_or);
+      list ($kw_sql, $kw_sql_params) = search_keywords_in_fields (
+        $arr_keywords, [ "$tos.details", "$tos.summary", "$tos.bug_id"],
+        $and_or
+      );
 
       $sql .= " AND $kw_sql ";
-      $sql_params = array_merge($sql_params, $kw_sql_params);
+      $sql_params = array_merge ($sql_params, $kw_sql_params);
 
       if ($only_group_id)
         {
           # $search_without_group_id can be set to avoid restricting search
           # to a group even if group_id is set.
-          $sql .= " AND ".$type_of_search.".group_id=? ";
+          $sql .= " AND $tos.group_id = ? ";
           $sql_params[] = $only_group_id;
         }
 
-      $sql .= " AND ".$type_of_search.".spamscore < 5 "
-        . "GROUP BY bug_id,summary,date,user_name "
-        . "ORDER BY ".$type_of_search.".date DESC ";
+      $sql .= " AND $tos.spamscore < 5
+        GROUP BY bug_id, summary, date, user_name ORDER BY $tos.date DESC ";
     }
-  else
-    exit_error(_("Invalid search."));
 
-  $sql .= " LIMIT ?,?";
-  $sql_params[] = intval($offset);
+  $sql .= " LIMIT ?, ?";
+  $sql_params[] = intval ($offset);
   $sql_params[] = $max_rows + 1;
-  return db_execute($sql, $sql_params);
+  return db_execute ($sql, $sql_params);
 }
 
 function search_exact ($keywords)
 {
-# Find the characters that maybe for a non-precise search. No need to continue
-# if it they are present.
-  $non_precise_key1 = strpos($keywords, '*' );
-  $non_precise_key2 = strpos($keywords, '%' );
+  # Find the characters that maybe for a non-precise search.
+  # No need to continue if it they are present.
+  $non_precise_key1 = strpos ($keywords, '*');
+  $non_precise_key2 = strpos ($keywords, '%');
 
   if (!($non_precise_key1 === false && $non_precise_key2 === false))
     return;
-  $arr_keywords = explode(' ', $keywords);
-  $question_marks = implode(',', array_fill(0, count($arr_keywords), '?'));
-  $sql = "SELECT group_name,unix_group_name,short_description,name
-             FROM groups,group_type
-          WHERE type=type_id AND group_name IN ($question_marks)
-          AND status='A' AND is_public='1'";
-  $result = db_execute($sql,$arr_keywords);
-  $num_rows = db_numrows($result);
+  $arr_keywords = explode (' ', $keywords);
+  $ph = utils_in_placeholders ($arr_keywords);
+  $sql = "
+    SELECT group_name, unix_group_name, short_description, name
+    FROM groups, group_type
+    WHERE
+      type = type_id AND group_name $ph AND status = 'A' AND is_public = '1'";
+  $result = db_execute ($sql, $arr_keywords);
+  $num_rows = db_numrows ($result);
 
   if ($num_rows != 1)
     return;
   print "<h2>";
-  print
-# TRANSLATORS: this is a title for search results when exactly one item is found.
-        _("Unique project search result");
-  print "</h2>\n";
-  printf('<p>'._("Search string was: %s.")."</p>\n",
-         '<strong>'.htmlspecialchars($keywords).'</strong>');
-
-  $title_arr = array();
-  $title_arr[] = _("Project");
-  $title_arr[] = _("Description");
-  $title_arr[] = _("Type");
-
-  print html_build_list_table_top($title_arr);
+  # TRANSLATORS: this is a title for search results when exactly one item is found.
+  print _("Unique group search result");
+  print "</h2>\n<p>";
+  printf (_("Search string was: %s."),
+    '<strong>' . htmlspecialchars ($keywords) . '</strong>'
+  );
+  print "</p>\n";
+  print html_build_list_table_top ([_("Group"), _("Description"), _("Type")]);
   print "\n";
-  $row = db_fetch_array($result);
-  print "<tr><td><a href=\"../projects/"
-."${row['unix_group_name']}\">${row['group_name']}</a></td>
-  <td>${row['short_description']}</td>
-  <td>${row['name']}</td></tr>
-  </table>\n";
+  $row = db_fetch_array ($result);
+  $name = gettext ($row['name']);
+  print "<tr><td><a href=\"../projects/{$row['unix_group_name']}\">"
+    . "{$row['group_name']}</a></td>\n<td>{$row['short_description']}</td>\n"
+    . "<td>$name</td></tr>\n</table>\n";
 }
 ?>
