@@ -449,7 +449,9 @@ function trackers_data_get_all_report_fields ($report_id = 100)
     SELECT * FROM " . ARTIFACT . "_report_field WHERE report_id = ?",
     [$report_id]
   );
-
+  $flags = ['show_on_query' => 0, 'show_on_result' => 1,
+    'place_query' => null, 'place_result' => null, 'col_width' => null
+  ];
   while ($arr = db_fetch_array ($res))
     {
       $field = $arr['field_name'];
@@ -459,43 +461,19 @@ function trackers_data_get_all_report_fields ($report_id = 100)
           # bug_id should always show up.
           $arr['show_on_result'] = 1;
         }
-      $field_id = trackers_data_get_field_id ($field);
-      $BF_USAGE_BY_NAME[$field]['show_on_query'] =
-        $BF_USAGE_BY_ID[$field_id]['show_on_query'] = $arr['show_on_query'];
-
-      $BF_USAGE_BY_NAME[$field]['show_on_result'] =
-        $BF_USAGE_BY_ID[$field_id]['show_on_result'] = $arr['show_on_result'];
-
-      $BF_USAGE_BY_NAME[$field]['place_query'] =
-        $BF_USAGE_BY_ID[$field_id]['place_query'] = $arr['place_query'];
-
-      $BF_USAGE_BY_NAME[$field]['place_result'] =
-        $BF_USAGE_BY_ID[$field_id]['place_result'] = $arr['place_result'];
-
-      $BF_USAGE_BY_NAME[$field]['col_width'] =
-        $BF_USAGE_BY_ID[$field_id]['col_width'] = $arr['col_width'];
+      $id = trackers_data_get_field_id ($field);
+      foreach ($flags as $f => $ignored)
+        $BF_USAGE_BY_NAME[$field][$f] = $BF_USAGE_BY_ID[$id][$f] = $arr[$f];
     }
   # Every query form should have 'bug_id'; if it hasn't, add it.
   if (!$have_bug_id)
     {
       if (db_numrows ($res) > 0)
-        error_log ("No bug it found in query form #" . $report_id);
+        error_log ("No bug it found in query form #$report_id");
       $field = 'bug_id';
-      $field_id = trackers_data_get_field_id ($field);
-      $BF_USAGE_BY_NAME[$field]['show_on_query'] =
-        $BF_USAGE_BY_ID[$field_id]['show_on_query'] = 0;
-
-      $BF_USAGE_BY_NAME[$field]['show_on_result'] =
-        $BF_USAGE_BY_ID[$field_id]['show_on_result'] = 1;
-
-      $BF_USAGE_BY_NAME[$field]['place_query'] =
-        $BF_USAGE_BY_ID[$field_id]['place_query'] = null;
-
-      $BF_USAGE_BY_NAME[$field]['place_result'] =
-        $BF_USAGE_BY_ID[$field_id]['place_result'] = null;
-
-      $BF_USAGE_BY_NAME[$field]['col_width'] =
-        $BF_USAGE_BY_ID[$field_id]['col_width'] = null;
+      $id = trackers_data_get_field_id ($field);
+      foreach ($flags as $f => $v)
+        $BF_USAGE_BY_NAME[$field][$f] = $BF_USAGE_BY_ID[$id][$f] = $v;
     }
   return db_numrows ($res) > 0;
 }
@@ -618,6 +596,11 @@ function trackers_data_mandatory_flag ($field, $by_field_id = false)
   return trackers_data_custom_val ($field, 'empty_ok', $by_field_id);
 }
 
+function trackers_data_do_keep_history ($field, $by_field_id = false)
+{
+  return trackers_data_custom_val ($field, 'keep_history', $by_field_id);
+}
+
 function trackers_data_is_required ($field, $by_field_id = false)
 {
   return trackers_data_field_val ($field, 'required', $by_field_id);
@@ -1389,7 +1372,7 @@ function trackers_data_append_canned_response ($details, $canned_response)
         [$response]
       );
 
-      if (!$res || db_numrows ($res) <= 0)
+      if (db_numrows ($res) <= 0)
         {
           fb (_("Unable to use canned response"), 1);
           continue;
@@ -1421,14 +1404,9 @@ function trackers_data_handle_update (
   # Return true if bug updated, false if nothing changed or
   # DB update failed.
 
-  # Make sure absolutely required fields are not empty
-  # yeupou, 2005-11: why is canned_response absolutely required?
-  if (!$group_id || !$item_id || !$canned_response)
-    {
-      dbg ("params were group_id:$group_id item_id:$item_id "
-          . "canned_response:$canned_response");
-      exit_missing_param ();
-    }
+  # Make sure absolutely required fields are not empty.
+  if (!$group_id || !$item_id)
+    exit_missing_param (['group_id', 'item_id']);
 
   # Make sure mandatory fields are not empty, otherwise we want the form
   # to be re-submitted.
@@ -1594,6 +1572,8 @@ function trackers_data_handle_update (
       $change_exists = 1;
       fb (_("Comment added"), 0);
       $dtext = htmlspecialchars ($details);
+      if (empty ($vfl['comment_type_id']))
+        $vfl['comment_type_id'] = false;
       trackers_data_add_history (
         'details', $dtext, '', $item_id, $vfl['comment_type_id']
       );
@@ -1612,7 +1592,7 @@ function trackers_data_handle_update (
   if (ARTIFACT == 'cookbook')
     {
       $details = htmlspecialchars ($vfl['details']);
-      $previous_details = db_result ($result,0,'details');
+      $previous_details = db_result ($result, 0, 'details');
 
       if ($details != $previous_details)
         {
@@ -2243,13 +2223,13 @@ function trackers_data_get_value (
 
   # Look for project specific values first...
   $result = db_execute ($sql, $args);
-  if ($result && db_numrows ($result) > 0)
+  if (db_numrows ($result) > 0)
     return db_result ($result, 0, 'value');
 
   # ... if it fails, look for system wide default values (group_id=100)...
   $args[0] = 100;
   $result = db_execute ($sql, $args);
-  if ($result && db_numrows ($result) > 0)
+  if (db_numrows ($result) > 0)
     return db_result ($result, 0, 'value');
 
   # No value found for this value id.
