@@ -112,8 +112,7 @@ function format_item_details (
 
   # Provide a shortcut to the original submission, if more than 5 comments
   # and not in reversed order.
-  if (!$ascii && empty($_REQUEST['printer'])
-      && $max_entries > 5 && !$user_pref_fromoldertonewer)
+  if (!$ascii && $max_entries > 5 && !$user_pref_fromoldertonewer)
     {
       $jumpto_text = _("Jump to the original submission");
       if (ARTIFACT == "cookbook")
@@ -191,9 +190,6 @@ function format_item_details (
           else
             $spammer_user_name = _("anonymous");
 
-          # If we are in printer mode, simply skip if.
-          if (!empty ($_REQUEST['printer']))
-            continue;
           $own_post = user_isloggedin () && user_getid () == $entry['user_id'];
 
           # The admin may actually want to see the incriminated item.
@@ -353,8 +349,7 @@ function format_item_details (
       # For performance reason, do not check here if the user already
       # flagged the comment as spam, it will be done only if the user tries
       # to do it twice.
-      if (user_isloggedin() && !$icon
-          && $poster_id != user_getid () && empty ($_REQUEST['printer']))
+      if (user_isloggedin() && !$icon && $poster_id != user_getid ())
         {
           # Surround by two line breaks, to keep that link clearly
           # separated from anything else, to avoid clicks by error.
@@ -372,6 +367,55 @@ function format_item_details (
   return $out;
 }
 
+function format_message_trailer ($bug_ref)
+{
+  return "\n    _______________________________________________________\n\n"
+  . "Reply to this item at:\n\n  <$bug_ref>";
+}
+
+function format_item_regular_fields ($res, $group_id)
+{
+  $body = '';
+  while ($field_name = trackers_list_all_fields ())
+    {
+      # If the field is a special field or if not used by this group
+      # then skip it. Otherwise print it in ASCII format.
+      if (trackers_data_is_special ($field_name))
+        continue;
+      if (!trackers_data_is_used ($field_name))
+        continue;
+      $body .= trackers_field_display (
+        $field_name, $group_id, $res[$field_name], false, true, true, true
+      );
+      $body .= "\n";
+    }
+  return $body;
+}
+
+function format_item_summary ($res, $bug_ref, $artifact)
+{
+  $group_id = $res['group_id'];
+  $item_id = $res['bug_id'];
+  $body = "URL:\n  <$bug_ref>\n\n";
+  $body .= trackers_field_display (
+    'summary', $group_id, $res['summary'], false, true, true, true
+  );
+  $body .= "\n";
+  $body .= sprintf ("%25s %s\n", "Group:", group_getname ($group_id));
+  $body .= trackers_field_display (
+    'submitted_by', $group_id, $res['submitted_by'], false, true, true, true
+  );
+  $body .= "\n";
+  $body .= trackers_field_display (
+    'date', $group_id, $res['date'], false, true, true, true
+  );
+  $body .= "\n" . format_item_regular_fields ($res, $group_id);
+  if (ARTIFACT === $artifact)
+    $body .= "\n\n" . format_item_details ($item_id, $group_id, true)
+      . "\n\n" . format_item_attached_files ($item_id, $group_id, true);
+  return $body;
+}
+
 function format_item_changes ($changes, $item_id, $group_id)
 {
   # FIXME: strange, with %25s it does not behave exactly like
