@@ -25,10 +25,6 @@ require_once ('../include/database.php');
 require_directory ('search');
 require_directory ('trackers');
 
-# Make this page register global off compliant.
-register_globals_off ();
-
-# Obtain general user info.
 $res_user =
   db_execute ("SELECT * FROM user WHERE user_id = ?", [user_getid ()]);
 $row_user = db_fetch_array ($res_user);
@@ -36,8 +32,6 @@ $row_user = db_fetch_array ($res_user);
 # Obtain approval_user_gen_email() for site specific content.
 utils_get_content ("my/request_for_inclusion");
 
-# Updates.
-# Watchee add.
 extract (sane_import ('request',
   [
     'strings' => [['func', ['addwatchee', 'delwatchee']]],
@@ -100,10 +94,12 @@ function send_pending_user_email ($group_id, $user_id, $user_message)
   );
 
   sendmail_mail (
-    user_getname(), $admin_list,
+    ['from' => user_getname (), 'to' => $admin_list],
     # TRANSLATORS: the argument is group name.
-    sprintf (_("Membership request for group %s"), $row_grp['group_name']),
-    $message, $row_grp['unix_group_name'], "usermanagement"
+    [ 'subject' =>
+        sprintf (_("Membership request for group %s"), $row_grp['group_name']),
+      'body' => $message],
+    [ 'group' => $row_grp['unix_group_name'], 'tracker' => "usermanagement"]
   );
 }
 
@@ -144,7 +140,7 @@ if ($update)
           {
             fb (_("When joining you must provide a message for the\n"
                   . "administrator, a short explanation of why you want "
-                  . "to join this project."), 1
+                  . "to join this group."), 1
             );
             continue;
           }
@@ -223,16 +219,10 @@ $rows_w = db_numrows ($result_w);
 
 if (!$result_w || $rows_w < 1)
   {
-    print '<p>' . _("You are not watching any partners.") . "</p>\n";
-    print '<p>'
-      . _("Watching a partner (receiving a copy of all notifications\n"
-          . "sent to them) permits you to be their backup when they are "
-          . "away from the\noffice, or to review all their activities "
-          . "on a project.");
-    print "</p>\n<p>";
+    print '<p>' . _("You are not watching any partners.") . "</p>\n<p>";
     print _("To watch someone, follow the &ldquo;Watch partner&rdquo; link\n"
-            . "in the project memberlist page. You need to be member of that "
-            . "project.");
+            . "in group memberlist page. You need to be member of that "
+            . "group.");
     print "<br />\n";
     print db_error ();
   }
@@ -284,8 +274,8 @@ if ($watchers)
     # list of watchers.
     printf (
       ngettext (
-        'My own notifications are currently watched by %1$s user: %2$s.',
-        'My own notifications are currently watched by %1$s users: %2$s.',
+        'I am currently watched by %1$s user: %2$s.',
+        'I am currently watched by %1$s users: %2$s.',
         $watchers_num
       ),
       $watchers_num, $watchers
@@ -293,7 +283,7 @@ if ($watchers)
     print "</p>\n";
   }
 else
-  print '<p>' . _("Nobody is currently watching my own notifications.")
+  print '<p>' . _("Nobody is currently watching me.")
     . "</p>\n";
 
 print $HTML->box_bottom ();
@@ -302,11 +292,11 @@ print $HTML->box_top (_("Request for Inclusion"), '', 1);
 print "<div class='boxitem'>\n";
 print '<p>';
 print
-  _("Type below the name of the project you want to contribute to. "
-    . "Joining\na project means getting write access to the project "
-    . "repositories and trackers,\nand involves responsibilities.  Therefore, "
-    . "usually you would first contact the\nproject developers (e.g., using "
-    . "a project mailing list) before requesting\nformal inclusion using "
+  _("Type below the name of the group you want to contribute to.\n"
+    . "Joining a group means getting write access to the repositories\n"
+    . "of the group, and involves responsibilities.  Therefore,\n"
+    . "usually you would first contact group members (e.g., using\n"
+    . "a group mailing list) before requesting formal inclusion using\n"
     . "this form.");
 print "</p>\n\n";
 
@@ -319,10 +309,12 @@ print form_submit (_("Search Groups"), "Submit", false, true);
 print "</form>\n\n</div><!-- end boxitem -->\n";
 
 extract (sane_import ('request', ['pass' => 'words']));
+if (!is_scalar ($words))
+  $words = '';
 if ($words)
   {
     # Avoid to big search by asking for more than 1 characters.
-    # Restricting to more than 2 chars skips a great deal of project names
+    # Restricting to more than 2 chars skips a great deal of group names
     # (eg: gv, gdb).
     $result_search = 0;
     if (strlen ($words) > 1)
@@ -347,14 +339,13 @@ if ($words)
         print '<p>';
         print
           _("To request inclusion in one or several groups, check the\n"
-            . "correspondent boxes, write a meaningful message "
-            . "for the project administrator\nwho will approve "
-            . "or disapprove the request, and submit the form.");
+            . "boxes, write a meaningful message for group administrator\n"
+            . "who will approve or discard the request, and submit the form.");
         print "</p>\n" . form_header ($_SERVER['PHP_SELF']);
 
         while ($val = db_fetch_array ($result_search))
           {
-            if (user_is_group_member ($row_user['user_id'], $val['group_id']))
+            if (user_check_ismember ($row_user['user_id'], $val['group_id']))
               {
                 print "+ {$val['group_name']} ";
                 print _('(already a member)') . "<br />\n";
@@ -380,7 +371,7 @@ print html_splitpage (2);
 if (!$result || $rows < 1)
   {
     print $HTML->box_top (_("My Groups"), '', 1);
-    print _("You're not a member of any public projects");
+    print _("You're not a member of any public group");
     print $HTML->box_bottom (1);
   }
 else
