@@ -70,7 +70,7 @@ if ($people_cat)
     site_header (['title' => _('Change Categories')]);
     # List of possible categories for this group.
     $result = db_query ("SELECT category_id, name FROM people_job_category");
-    if ($result && db_numrows ($result) > 0)
+    if (db_numrows ($result) > 0)
       utils_show_result_set (
         $result, _("Existing Categories"), 'people_cat', '2'
       );
@@ -95,7 +95,7 @@ elseif ($people_skills)
     # List of possible people_groups for this group.
     $result = db_query ("SELECT skill_id, name FROM people_skill");
     print "<p>";
-    if ($result && db_numrows ($result) > 0)
+    if (db_numrows ($result) > 0)
       utils_show_result_set (
         $result, _("Existing Skills"), "people_skills", '2'
       );
