@@ -21,9 +21,8 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-require_once('../include/init.php');
-register_globals_off();
-require_once('../include/people/general.php');
+require_once ('../include/init.php');
+require_once ('../include/people/general.php');
 
 extract (sane_import ('get',
   [
@@ -47,7 +46,7 @@ if ($group_id)
   {
     site_project_header (
       [
-        'title' => _('Project Help Wanted'),
+        'title' => _('Group Help Wanted'),
         'group' => $group_id, 'context' => 'people',
       ]
     );
