@@ -2,7 +2,7 @@
 # Offer user's keys for download.
 #
 # Copyright (C) 2002-2005 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2017, 2022 Ineiev
+# Copyright (C) 2017, 2022, 2023 Ineiev
 #
 # This file is part of Savane.
 #
@@ -19,32 +19,29 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-require_once('../include/init.php');
-register_globals_off();
+require_once ('../include/init.php');
 extract (sane_import ('get', ['digits' => 'user_id']));
 
 if (empty ($user_id))
-  exit_error(_("User not found."));
+  exit_missing_param (['user_id']);
 
-$result = db_execute ("SELECT user_name, gpg_key FROM user WHERE user_id = ?",
-                      array($user_id));
+$result = db_execute (
+  "SELECT user_name, gpg_key FROM user WHERE user_id = ?", [$user_id]
+);
 
-if (!$result || db_numrows ($result) < 1)
-  exit_error(_("User not found."));
+if (db_numrows ($result) < 1)
+  exit_error (_("User not found."));
 
 $user_name = db_result ($result, 0, 'user_name');
 $gpg_key = db_result ($result, 0, 'gpg_key');
 
 if (!$gpg_key)
-  exit_error( _("This user hasn't registered a GPG key."));
+  exit_error (_("This user hasn't registered a GPG key."));
 
 header ('Content-Type: application/pgp-keys');
 header ("Content-Disposition: attachment; filename=$user_name-key.gpg");
-$description =
-  sprintf (
-    # TRANSLATORS: the argument is user's name.
-    _('GPG Key of the user %s'), $user_name
-  );
-header("Content-Description: $description");
+# TRANSLATORS: the argument is user's name.
+$description = sprintf (_('GPG Key of the user %s'), $user_name);
+header ("Content-Description: $description");
 print $gpg_key;
 ?>
