@@ -4,7 +4,7 @@
 # Copyright (C) 2003-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2003-2006 Yves Perrin <yves.perrin--cern.ch>
 # Copyright (C) 2007  Sylvain Beucler
-# Copyright (C) 2017, 2018, 2022 Ineiev
+# Copyright (C) 2017, 2018, 2022, 2023 Ineiev
 #
 # This file is part of Savane.
 #
@@ -21,12 +21,14 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-require_once('../include/init.php');
+require_once ('../include/init.php');
 
 extract (sane_import ('request',
   [
     'digits' =>
-      ['type', 'offset', 'max_rows', 'only_group_id', ['exact', [0, 1]]],
+      [ 'type', 'only_group_id', ['offset', [0, 410338673]],
+        ['max_rows', [1, 4913]], ['exact', [0, 1]]
+      ],
     'strings' => [
       [
         'type_of_search',
@@ -37,11 +39,17 @@ extract (sane_import ('request',
   ]
 ));
 
-if (!$words)
+if (empty ($offset))
+  $offset = 0;
+
+if (empty ($max_rows))
+  $max_rows = 25;
+
+if (!$words || !is_scalar ($words))
   {
-    search_send_header();
+    search_send_header ();
     print '<p>' . _("Enter your search words above.") . "</p>\n";
-    $HTML->footer(array());
+    $HTML->footer ([]);
     exit;
   }
 
@@ -87,7 +95,7 @@ if ($type_of_search == 'soft')
     search_send_header();
     search_exact($words);
     print_search_heading();
-    $title_arr = [_("Project"), _("Description"), _("Type")];
+    $title_arr = [_("Group"), _("Description"), _("Type")];
 
     print html_build_list_table_top ($title_arr);
     print "\n";
@@ -99,18 +107,19 @@ if ($type_of_search == 'soft')
           [db_result ($result, $i, 'type')]
         );
 
-        print '<tr class="'. html_get_alt_row_color($i)
+        print '<tr class="' . html_get_alt_row_color($i)
           . '"><td><a href="../projects/'
           . db_result ($result, $i, 'unix_group_name')
           . '">' . db_result ($result, $i, 'group_name')
           . "</a></td>\n<td>"
           . db_result ($result, $i, 'short_description')
           . "</td>\n<td>"
-          . db_result ($res_type, 0, 'name') . "</td>\n</tr>\n";
+          . gettext (db_result ($res_type, 0, 'name')) . "</td>\n</tr>\n";
       }
     print "</table>\n";
     print '<p>'
-. _('Note that <strong>private</strong> projects are not shown on this page.')
+      . _("Note that <strong>private</strong> groups are not shown "
+          . "on this page.")
       . "</p>\n";
     finish_page ();
   }
