@@ -100,10 +100,9 @@ if ($delete)
 $name_matching = function ($trackers, $vcs_list)
 {
   $names = [
-    'name' => 'name',
     'specialchars' => [
-      'description',  'base_host', 'homepage_scm',
-      'admin_email_adress', # Sic! adress not address
+      'name', 'description',  'base_host', 'homepage_scm',
+      'admin_email_adress', # Sic! adress not address, single 'd'.
     ],
     'true' => []
   ];
@@ -204,7 +203,7 @@ if (empty ($type_id))
     {
       $last = $usr['type_id'];
       print "<a href=\"$php_self?type_id=$last\">";
-      printf (no_i18n ('Type #%1$s: %2$s'), $last, gettext ($usr['name']));
+      printf (no_i18n ('Type #%1$s: %2$s'), $last, $usr['name']);
       print "</a><br />\n";
     }
   # Find an appropriate unused group type ID (skip value 100).
