@@ -2,39 +2,38 @@
 # Copyright (C) 1999-2000 The SourceForge Crew
 # Copyright (C) 2004-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2004-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2017 Ineiev
+# Copyright (C) 2017, 2023 Ineiev
 #
 # This file is part of Savane.
-# 
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
 # License, or (at your option) any later version.
-# 
+#
 # Savane is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU Affero General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-require_once('../include/init.php');
-register_globals_off();
+require_once ('../include/init.php');
 
 # We don't internationalize messages in this file because they are
 # for Savannah admins who use English.
-function no_i18n($string)
+function no_i18n ($string)
 {
   return $string;
 }
 
-site_admin_header(array('title'=>no_i18n("Home"),'context'=>'admhome'));
+site_admin_header (['title' => no_i18n ("Home"), 'context' => 'admhome']);
 
 # Include the /testconfig.php that can be run on 127.0.0.1
 # when Savane is not yet running itself.
 $inside_siteadmin = true;
-include('../testconfig.php');
+include ('../testconfig.php');
 
-site_admin_footer(array());
+site_admin_footer ([]);
 ?>
