@@ -542,7 +542,7 @@ $reference = 'include/init.php';
   unset($out['forim_id']);
   $out['forum_id'] = null;
 
-  $in['printer'] = 1;
+  $in['print-me'] = 1;
 
   test_sane_import ($in, $names, $out);
 
@@ -555,42 +555,6 @@ $reference = 'include/init.php';
   test_sane_import ($in, $names, $out);
 }
 
-# The test is the same the next two files.
-$reference = 'include/markup.php';
-$reference = 'include/theme.php';
-{
-  $names = ['true' => 'printer'];
-  $in = [
-    'printer' => 1,
-    'group' => 'administration'
-  ];
-
-  $out = ['printer' => true];
-
-  test_sane_import ($in, $names, $out);
-
-  extract($out);
-
-  if (empty ($printer))
-    print "empty\n";
-
-  if ($printer == 1)
-    ; # OK.
-  else
-    print "printer != 1\n";
-
-  $in = ['group' => 'administration'];
-  $out = ['printer' => null];
-
-  test_sane_import ($in, $names, $out);
-
-  extract($out);
-  if ($printer)
-    print '$printer' . "\n";
-
-  unset($printer);
-}
-
 $reference = 'include/my/general.php';
 {
   $role = 'role';
@@ -1139,7 +1103,6 @@ $reference = 'include/trackers_run/browse.php';
         ['order', '/^([_a-zA-Z-][_[:alnum:]-]*)?$/'],
         ['morder', '/^[,<>_[:alnum:]-]*$/']
       ],
-    'true' => 'printer'
   ];
   $in = [
     'chunksz' => 40,
@@ -1160,7 +1123,6 @@ $reference = 'include/trackers_run/browse.php';
     'history_event' => 'modified',
     'history_date' => '1983-09-27',
     'morder' => 'bug_id<,status>',
-    'printer' => 'printer'
   ];
   $out = $in;
   $out['func'] = 'browse';
@@ -1232,7 +1194,6 @@ $reference = 'include/trackers_run/index.php';
 {
   $names = [
     'funcs' => 'func',
-    'true' => 'printer',
     'digits' => ['item_file_id', 'item_cc_id']
   ];
   $in = [
@@ -1241,7 +1202,6 @@ $reference = 'include/trackers_run/index.php';
     'item_cc_id' => 289
   ];
   $out = $in;
-  $out['printer'] = null;
   test_sane_import ($in, $names, $out);
   $names = [
     'hash' => 'form_id',
@@ -2075,7 +2035,9 @@ $reference = 'search/index.php';
 {
   $names = [
     'digits' =>
-      ['type', 'offset', 'max_rows', 'only_group_id', ['exact', [0, 1]]],
+      [ 'type', 'only_group_id', ['offset', [0, 410338673]],
+        ['max_rows', [1, 4913]], ['exact', [0, 1]]
+      ],
     'strings' => [
       [
         'type_of_search',
@@ -2089,6 +2051,10 @@ $reference = 'search/index.php';
     'only_group_id' => 4, 'type_of_search' => 'soft', 'words' => 'w',
   ];
   test_sane_import ($in, $names, $out);
+  $in['offset'] = -1; $out['offset'] = 1;
+  test_sane_import ($in, $names, $out);
+  $in['max_rows'] = 0; $out['max_rows'] = null;
+  test_sane_import ($in, $names, $out);
 }
 
 $reference = 'sendmessage.php';
@@ -2172,9 +2138,8 @@ $reference = 'siteadmin/group_type.php';
   ];
 
   $names = [
-    'name' => 'name',
     'specialchars' => [
-      'description',  'base_host', 'homepage_scm',
+      'name', 'description',  'base_host', 'homepage_scm',
       'admin_email_adress', # Sic! adress not address
     ],
     'true' => []
@@ -2220,7 +2185,7 @@ $reference = 'siteadmin/group_type.php';
     $in[$n] = $out[$n] = true;
   foreach ($names['specialchars'] as $n)
     $in[$n] = $out[$n] = $n;
-  $in['name'] = $out['name'] = 'name';
+  $in['name'] = $out['name'] = 'Official GNU software';
   test_sane_import ($in, $names, $out);
 }
 
