@@ -3,7 +3,7 @@
 # Instructions about Hg usage.
 #
 # Copyright (C) 2008 Sylvain Beucler
-# Copyright (C) 2017 Ineiev <ineiev@gnu.org>
+# Copyright (C) 2017, 2019 Ineiev <ineiev@gnu.org>
 #
 # This file is part of Savane.
 #
@@ -20,16 +20,36 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+include dirname (__FILE__) . '/../fingerprints.php';
+
 global $project;
 
-print '<h2>'._('Anonymous checkout:').'</h2>
+print '<h3>' . _('Anonymous read-only access') . '</h3>
 
-<pre>hg clone http://hg.'
-  .$project->getTypeBaseHost() . '/hgweb'
-  .preg_replace(':/srv/hg:', '', $project->getTypeDir('hg')).'
+<pre>hg clone https://hg.'
+  . $project->getTypeBaseHost() . '/hgweb'
+  . preg_replace(':/srv/hg:', '', $project->getTypeDir('hg')) . '
 </pre>
 
-<h2>'._('More information').'</h2>
+<h3>' . _('Developer write access (SSH)') . '</h3>
+
+';
+
+$username = user_getname();
+if ($username == "NA")
+   # For anonymous user.
+   $username = '&lt;<i>'._('membername').'</i>&gt;';
+print '
+<pre>hg clone ssh://'
+  . $username . '@hg.' . $project->getTypeBaseHost() . "/"
+  . $project->getUnixName() . '</pre>
+
+<p>'
+. _('The SSHv2 public key fingerprints for the machine hosting the source
+trees are:') . "</p>\n" . $vcs_fingerprints;
+
+print '
+<h3>'._('More information').'</h3>
 
 <p><a href="//savannah.gnu.org/maintenance/UsingHg">
 https://savannah.gnu.org/maintenance/UsingHg</a></p>
